@@ -382,9 +382,13 @@ send_token(int sock, void *token, size_t token_length, struct timeval *to)
 	 case 0: ret = EDG_WLL_GSS_ERROR_TIMEOUT;
 		 goto end;
 		 break;
-	 case -1: ret = EDG_WLL_GSS_ERROR_ERRNO;
-		  goto end;
-		  break;
+	 case -1:
+		if (errno == EINTR) continue;
+		else {
+			ret = EDG_WLL_GSS_ERROR_ERRNO;
+			goto end;
+		}
+		break;
       }
 
       count = write(sock, ((char *)token) + num_written,
@@ -434,7 +438,7 @@ send_gss_token(int sock, gss_OID mech, void *token, size_t token_length, struct
 static int
 recv_token(int sock, void *token, size_t token_length, struct timeval *to)
 {
-   ssize_t count;
+   ssize_t count = -1;
    fd_set fds;
    struct timeval timeout,before,after;
    int ret;
@@ -453,8 +457,11 @@ recv_token(int sock, void *token, size_t token_length, struct timeval *to)
 	    goto end;
 	    break;
 	 case -1:
-	    ret = EDG_WLL_GSS_ERROR_ERRNO;
-	    goto end;
+	    if (errno == EINTR) continue;
+	    else {
+		ret = EDG_WLL_GSS_ERROR_ERRNO;
+		goto end;
+	    }
 	    break;
       }
       
@@ -609,6 +616,7 @@ recv_gss_token(int sock, gss_OID mech, void **token, size_t *token_length, struc
     return 0;
 }
 
+#ifndef NO_GLOBUS_GSSAPI
 static int
 create_proxy(const char *cert_file, const char *key_file, char **proxy_file)
 {
@@ -681,6 +689,7 @@ end:
 
    return ret;
 }
+#endif
 
 static int
 destroy_proxy(char *proxy_file)
@@ -1570,7 +1579,9 @@ int
 edg_wll_gss_initialize(void)
 {
    int ret = 0;
+#ifndef NO_GLOBUS_GSSAPI
    int index;
+#endif
 
 #ifdef GLITE_LBU_THREADED
    pthread_mutex_lock(&init_lock);
